/*
 * cordova is available under *either* the terms of the modified BSD license *or* the
 * MIT License (2008). See http://opensource.org/licenses/alphabetical for full text.
 *
 * Copyright (c) 2005-2010, Nitobi Software Inc.
 * Copyright (c) 2011, IBM Corporation
 */

/**
 * Constructor
 */
function NxtInAppBrowser() {
};

NxtInAppBrowser.CLOSE_EVENT = 0;
NxtInAppBrowser.LOCATION_CHANGED_EVENT = 1;

/**
 * Display a new browser with the specified URL.
 * This method loads up a new web view in a dialog.
 *
 * @param url           The url to load
 * @param options       An object that specifies additional options
 */
NxtInAppBrowser.prototype.showWebPage = function(url, options) {
    options = options || {
        showLocationBar: false,
		showNxtBar: false,
        locationBarAlign: "top"
    };
    cordova.exec(this._onEvent, this._onError, "NxtInAppBrowser", "showWebPage", [url, options]);
};

/**
 * Display a new browser with the specified URL.
 * This method loads up a new web view in a dialog.
 *
 * @param url           The url to load
 * @param options       An object that specifies additional options
 */
NxtInAppBrowser.prototype.showWebData = function(url, options) {
    options = options || {
        showLocationBar: false,
        showNxtBar: false,
        locationBarAlign: "top"
    };
    cordova.exec(this._onEvent, this._onError, "NxtInAppBrowser", "showWebData", [url, options]);
};

/**
 * Close the browser opened by showWebPage.
 */
NxtInAppBrowser.prototype.close = function() {
    cordova.exec(null, null, "NxtInAppBrowser", "close", []);
};

/**
 * Display a new browser with the specified URL.
 * This method starts a new web browser activity.
 *
 * @param url           The url to load
 * @param usecordova   Load url in cordova webview [optional]
 */
NxtInAppBrowser.prototype.openExternal = function(url, usecordova) {
    if (usecordova === true) {
        navigator.app.loadUrl(url);
    }
    else {
        cordova.exec(null, null, "NxtInAppBrowser", "open", [url, usecordova]);
    }
};

/**
 * Method called when the child browser has an event.
 */
NxtInAppBrowser.prototype._onEvent = function(data) {
    if (data.type == NxtInAppBrowser.CLOSE_EVENT && typeof window.plugins.nxtInAppBrowser.onClose === "function") {
        window.plugins.nxtInAppBrowser.onClose();
    }
    if (data.type == NxtInAppBrowser.LOCATION_CHANGED_EVENT && typeof window.plugins.nxtInAppBrowser.onLocationChange === "function") {
        window.plugins.nxtInAppBrowser.onLocationChange(data.location);
    }
};

/**
 * Method called when the child browser has an error.
 */
NxtInAppBrowser.prototype._onError = function(data) {
    if (typeof window.plugins.nxtInAppBrowser.onError === "function") {
        window.plugins.nxtInAppBrowser.onError(data);
    }
};

/**
 * Maintain API consistency with iOS
 */
NxtInAppBrowser.prototype.install = function(){
};

/**
 * Load InAppBrowser
 */

if(!window.plugins) {
    window.plugins = {};
}
if (!window.plugins.nxtInAppBrowser) {
    window.plugins.nxtInAppBrowser = new NxtInAppBrowser();
}